var NAVTREEINDEX0 =
{
"alloc_8h.html":[10,8,1,0],
"annotated.html":[11,0],
"ansi_8h.html":[10,8,8,0,0],
"array_8h.html":[10,6,0,0],
"audio-capture_8c-example.html":[13,9],
"audio-dsp-filter_8c-example.html":[13,8],
"audio-dsp-src_8c-example.html":[13,7],
"audio-src_8c-example.html":[13,6],
"audio_2raw-types_8h.html":[10,8,7,4],
"audio_2raw_8h.html":[10,8,7,5],
"audio_8h.html":[10,8,7,6],
"bluez-session_8c-example.html":[13,23],
"buffer_2buffer_8h.html":[10,8,1,1],
"buffer_2type-info_8h.html":[10,8,1,3],
"buffers-types_8h.html":[10,8,7,8],
"builder_8h.html":[10,8,0,0],
"chroma_8h.html":[10,8,7,24],
"classes.html":[11,1],
"client-node_8h.html":[10,7,0,0],
"client_8h.html":[10,4,3,0],
"color_8h.html":[10,8,7,25],
"compare_8h.html":[10,8,0,2],
"conf_8h.html":[10,6,1,0],
"control_2type-info_8h.html":[10,8,2,1],
"core_8h.html":[10,4,14,0],
"core_8h.html":[10,4,4,0],
"cpu_8h.html":[10,8,9,0,0],
"data-loop_8h.html":[10,5,11,0],
"dbus_8h.html":[10,8,9,1,0],
"debug_2buffer_8h.html":[10,8,3,0],
"debug_2dict_8h.html":[10,8,3,2],
"debug_2format_8h.html":[10,8,3,3],
"debug_2pod_8h.html":[10,8,3,7],
"defs_8h.html":[10,8,8,1,0],
"dsd_8h.html":[10,8,7,0],
"examples.html":[13],
"export-sink_8c-example.html":[13,19],
"export-source_8c-example.html":[13,20],
"export-spa-device_8c-example.html":[13,22],
"export-spa_8c-example.html":[13,21],
"factory_8h.html":[10,4,6,0],
"format-types_8h.html":[10,8,7,10],
"functions.html":[11,2,0,0],
"functions.html":[11,2,0],
"functions_a.html":[11,2,0,1],
"functions_b.html":[11,2,0,2],
"functions_c.html":[11,2,0,3],
"functions_d.html":[11,2,0,4],
"functions_e.html":[11,2,0,5],
"functions_f.html":[11,2,0,6],
"functions_g.html":[11,2,0,7],
"functions_h.html":[11,2,0,8],
"functions_i.html":[11,2,0,9],
"functions_j.html":[11,2,0,10],
"functions_k.html":[11,2,0,11],
"functions_l.html":[11,2,0,12],
"functions_m.html":[11,2,0,13],
"functions_n.html":[11,2,0,14],
"functions_o.html":[11,2,0,15],
"functions_p.html":[11,2,0,16],
"functions_q.html":[11,2,0,17],
"functions_r.html":[11,2,0,18],
"functions_s.html":[11,2,0,19],
"functions_t.html":[11,2,0,20],
"functions_u.html":[11,2,0,21],
"functions_v.html":[11,2,0,22],
"functions_vars.html":[11,2,1],
"functions_vars.html":[11,2,1,0],
"functions_vars_a.html":[11,2,1,1],
"functions_vars_b.html":[11,2,1,2],
"functions_vars_c.html":[11,2,1,3],
"functions_vars_d.html":[11,2,1,4],
"functions_vars_e.html":[11,2,1,5],
"functions_vars_f.html":[11,2,1,6],
"functions_vars_g.html":[11,2,1,7],
"functions_vars_h.html":[11,2,1,8],
"functions_vars_i.html":[11,2,1,9],
"functions_vars_j.html":[11,2,1,10],
"functions_vars_k.html":[11,2,1,11],
"functions_vars_l.html":[11,2,1,12],
"functions_vars_m.html":[11,2,1,13],
"functions_vars_n.html":[11,2,1,14],
"functions_vars_o.html":[11,2,1,15],
"functions_vars_p.html":[11,2,1,16],
"functions_vars_q.html":[11,2,1,17],
"functions_vars_r.html":[11,2,1,18],
"functions_vars_s.html":[11,2,1,19],
"functions_vars_t.html":[11,2,1,20],
"functions_vars_u.html":[11,2,1,21],
"functions_vars_v.html":[11,2,1,22],
"functions_vars_w.html":[11,2,1,23],
"functions_vars_x.html":[11,2,1,24],
"functions_vars_y.html":[11,2,1,25],
"functions_vars_z.html":[11,2,1,26],
"functions_w.html":[11,2,0,23],
"functions_x.html":[11,2,0,24],
"functions_y.html":[11,2,0,25],
"functions_z.html":[11,2,0,26],
"global_8h.html":[10,5,12,0],
"globals.html":[12,0,0],
"globals.html":[12,0],
"globals_a.html":[12,0,1],
"globals_b.html":[12,0,2],
"globals_c.html":[12,0,3],
"globals_d.html":[12,0,4],
"globals_defs.html":[12,6],
"globals_defs.html":[12,6,0],
"globals_defs_a.html":[12,6,1],
"globals_defs_b.html":[12,6,2],
"globals_defs_c.html":[12,6,3],
"globals_defs_d.html":[12,6,4],
"globals_defs_e.html":[12,6,5],
"globals_defs_f.html":[12,6,6],
"globals_defs_g.html":[12,6,7],
"globals_defs_h.html":[12,6,8],
"globals_defs_i.html":[12,6,9],
"globals_defs_j.html":[12,6,10],
"globals_defs_k.html":[12,6,11],
"globals_defs_l.html":[12,6,12],
"globals_defs_m.html":[12,6,13],
"globals_defs_n.html":[12,6,14],
"globals_defs_p.html":[12,6,15],
"globals_defs_r.html":[12,6,16],
"globals_defs_s.html":[12,6,17],
"globals_defs_t.html":[12,6,18],
"globals_defs_u.html":[12,6,19],
"globals_defs_v.html":[12,6,20],
"globals_defs_w.html":[12,6,21],
"globals_defs_z.html":[12,6,22],
"globals_e.html":[12,0,5],
"globals_enum.html":[12,4],
"globals_eval.html":[12,5,0],
"globals_eval.html":[12,5],
"globals_eval_a.html":[12,5,1],
"globals_eval_b.html":[12,5,2],
"globals_eval_c.html":[12,5,3],
"globals_eval_d.html":[12,5,4],
"globals_eval_e.html":[12,5,5],
"globals_eval_f.html":[12,5,6],
"globals_eval_h.html":[12,5,7],
"globals_eval_i.html":[12,5,8],
"globals_eval_l.html":[12,5,9],
"globals_eval_m.html":[12,5,10],
"globals_eval_n.html":[12,5,11],
"globals_eval_p.html":[12,5,12],
"globals_eval_s.html":[12,5,13],
"globals_eval_t.html":[12,5,14],
"globals_eval_v.html":[12,5,15],
"globals_f.html":[12,0,6],
"globals_func.html":[12,1],
"globals_func.html":[12,1,0],
"globals_func_a.html":[12,1,1],
"globals_func_b.html":[12,1,2],
"globals_func_c.html":[12,1,3],
"globals_func_d.html":[12,1,4],
"globals_func_e.html":[12,1,5],
"globals_func_f.html":[12,1,6],
"globals_func_g.html":[12,1,7],
"globals_func_h.html":[12,1,8],
"globals_func_i.html":[12,1,9],
"globals_func_j.html":[12,1,10],
"globals_func_l.html":[12,1,11],
"globals_func_m.html":[12,1,12],
"globals_func_n.html":[12,1,13],
"globals_func_p.html":[12,1,14],
"globals_func_r.html":[12,1,15],
"globals_func_s.html":[12,1,16],
"globals_func_t.html":[12,1,17],
"globals_func_u.html":[12,1,18],
"globals_func_v.html":[12,1,19],
"globals_func_w.html":[12,1,20],
"globals_g.html":[12,0,7],
"globals_h.html":[12,0,8],
"globals_i.html":[12,0,9],
"globals_j.html":[12,0,10],
"globals_k.html":[12,0,11],
"globals_l.html":[12,0,12],
"globals_m.html":[12,0,13],
"globals_n.html":[12,0,14],
"globals_p.html":[12,0,15],
"globals_r.html":[12,0,16],
"globals_s.html":[12,0,17],
"globals_t.html":[12,0,18],
"globals_type.html":[12,3],
"globals_u.html":[12,0,19],
"globals_v.html":[12,0,20],
"globals_vars.html":[12,2],
"globals_w.html":[12,0,21],
"globals_z.html":[12,0,22],
"graph_8h.html":[10,8,5,0],
"group__api__pw__core.html":[10,4],
"group__api__pw__ext.html":[10,7],
"group__api__pw__impl.html":[10,5],
"group__api__pw__util.html":[10,6],
"group__api__spa.html":[10,8],
"group__pw__array.html":[10,6,0],
"group__pw__array.html#ga0cfa9d60080b10e5256fb90979199132":[10,6,0,8],
"group__pw__array.html#ga20b2d5c76f5bd422da680284e2709164":[10,6,0,2],
"group__pw__array.html#ga2625032cf701f2e966cbebec6b960596":[10,6,0,11],
"group__pw__array.html#ga3045d41af637079f6cba71102050f119":[10,6,0,19],
"group__pw__array.html#ga41905dd179bcee03cceef47579e0a22e":[10,6,0,16],
"group__pw__array.html#ga47a9004f4bdadccc2f702b83c16e468d":[10,6,0,5],
"group__pw__array.html#ga5810ebafde298c24ad4f2a38e092a8a3":[10,6,0,13],
"group__pw__array.html#ga6f9d0650617e0837738f3e37a6731651":[10,6,0,17],
"group__pw__array.html#ga7acbb5b8fe524379b21e6eb8b9958aeb":[10,6,0,14],
"group__pw__array.html#ga85440beb42b600e73e18daa0f3733f18":[10,6,0,9],
"group__pw__array.html#ga8d035221a3657cf9d2ede737a62a7c77":[10,6,0,15],
"group__pw__array.html#ga9bf5018e1a0d7466dc4fcac3e3207939":[10,6,0,4],
"group__pw__array.html#gaa960ca693013e1b7fce13b0968db70b8":[10,6,0,12],
"group__pw__array.html#gab0a7f1be44fce5380425b1ffcc674cf2":[10,6,0,7],
"group__pw__array.html#gadc116ecc65a6fb6f1d207e64c167c6b3":[10,6,0,6],
"group__pw__array.html#gadf6a4fd9f9bd810eb374737b3d1169b2":[10,6,0,20],
"group__pw__array.html#gae8d9a82b23a44ceb033f7f6ce3b0621d":[10,6,0,21],
"group__pw__array.html#gae9cb8580392ca2b9f97868eb9931968a":[10,6,0,10],
"group__pw__array.html#gaedd836346a7503ad9b55f6db1135c7eb":[10,6,0,3],
"group__pw__array.html#gaee841e7ecaaeb7cb1916fc954efc8287":[10,6,0,18],
"group__pw__buffers.html":[10,5,9],
"group__pw__buffers.html#ga096d7e73ff412f6c49fce1a8a6d99733":[10,5,9,8],
"group__pw__buffers.html#ga4d3d02b0d5999f11792c89f8b5ec8591":[10,5,9,3],
"group__pw__buffers.html#ga614b706400e47939c545f56c67f276fa":[10,5,9,7],
"group__pw__buffers.html#ga7701d99e8558482b0c87d2e552b1cd10":[10,5,9,9],
"group__pw__buffers.html#ga8ddb8f1ed0b17399af2515ce930f5b14":[10,5,9,4],
"group__pw__buffers.html#ga9c3b4ae5b1b248c35220d86240706a31":[10,5,9,6],
"group__pw__buffers.html#gacb6d3cf39ad33726f3a034ae846c4751":[10,5,9,5],
"group__pw__buffers.html#gad3a48705dc944299d59417cfa5b35f9d":[10,5,9,2],
"group__pw__client.html":[10,4,3],
"group__pw__client.html#ga0052817a42d359a4b306d77717e2bec9":[10,4,3,29],
"group__pw__client.html#ga08028eb8b2bc7e721c22cd0683d0fd59":[10,4,3,5],
"group__pw__client.html#ga1144b60d4d77eb5b5bda140e6dd31e13":[10,4,3,14],
"group__pw__client.html#ga2e47a9955d2344ceeca575ddbfea546a":[10,4,3,21],
"group__pw__client.html#ga2e599d0e1c57ae7418e7a58604f30290":[10,4,3,10],
"group__pw__client.html#ga2effc0dcfd9a3dd90e72dde47f58fa62":[10,4,3,7],
"group__pw__client.html#ga33efb76dc1c04741209f7c313b0a6e6e":[10,4,3,15],
"group__pw__client.html#ga376200cda9564550fda412c327cab29d":[10,4,3,24],
"group__pw__client.html#ga44649b91990bb998e81a97c45fac4975":[10,4,3,18],
"group__pw__client.html#ga46fcb2a45cd729fd11659e81c4875339":[10,4,3,9],
"group__pw__client.html#ga534848e70aa11c5f41df3c8c9751c2bf":[10,4,3,27],
"group__pw__client.html#ga5aba78585d56fbbd77f87b7d841f633a":[10,4,3,28],
"group__pw__client.html#ga64aacff6f50a099bd9f4f292af5053a8":[10,4,3,11],
"group__pw__client.html#ga6ab68453545662580dfb9ef12eb99cc4":[10,4,3,19],
"group__pw__client.html#ga9429f541161b89136e87de99499d42d4":[10,4,3,26],
"group__pw__client.html#gab0377cbf13596f969016266bc277b60b":[10,4,3,13],
"group__pw__client.html#gab23fc368d6d3c8dc6737af396c8ebdc4":[10,4,3,6],
"group__pw__client.html#gaca345ef08d2fe2316b793b2721489e7d":[10,4,3,20],
"group__pw__client.html#gaca741a1eb7d2306a1d06f7236bdcdd53":[10,4,3,23],
"group__pw__client.html#gad6b676ec28f1d8598d37c3b73a4f06b9":[10,4,3,25],
"group__pw__client.html#gad7327a543c437159816d4256e84e370b":[10,4,3,16],
"group__pw__client.html#gae4b0f81c2ec7e2249624a5f3bbe3db2d":[10,4,3,8],
"group__pw__client.html#gae9c05c6686aa7db3f69466363e7b8077":[10,4,3,12],
"group__pw__client.html#gaf334e712707cd3d4fb97100f3baedeb0":[10,4,3,22]
};
